diff src/core/sat_main.py @ 2147:bca699faf416

core: added release name in constants + full version
author Goffi <goffi@goffi.org>
date Sun, 12 Feb 2017 19:23:34 +0100
parents 1bb9bf1b4150
children 4b78b4c7f805
line wrap: on
line diff
--- a/src/core/sat_main.py	Sun Feb 12 19:08:52 2017 +0100
+++ b/src/core/sat_main.py	Sun Feb 12 19:23:34 2017 +0100
@@ -129,14 +129,14 @@
 
     @property
     def full_version(self):
         """Return the full version of SàT (with extra data when in development mode)"""
         version = self.version
         if version[-1] == 'D':
             # we are in debug version, we add extra data
             try:
                 return self._version_cache
             except AttributeError:
-                self._version_cache = u"{} ({})".format(version, utils.getRepositoryData(sat))
+                self._version_cache = u"{} « {} » ({})".format(version, C.APP_RELEASE_NAME, utils.getRepositoryData(sat))
                 return self._version_cache
         else:
             return version
@@ -129,14 +129,14 @@
     @property
     def full_version(self):
-        """Return the full version of SàT (with extra data when in development mode)"""
+        """Return the full version of SàT (with release name and extra data when in development mode)"""
         version = self.version
         if version[-1] == 'D':